@@ -14,18 +14,17 @@
 
 #' Pareto Distribution
 #'
-#' Density, distribution function, quantile function, random generation
-#' and starting values for the
-#' Pareto distribution
-#' with scale and shape parameters.
-#'
+#' Probability density, cumulative distribution, 
+#' inverse cumulative distribution, random sample and starting values functions.
+#' 
+#' The pareto distribution has been deprecated as it is not suitable for SSD data.
 #' The functions are wrappers on the equivalent VGAM functions.
 #'
 #' @param x A numeric vector of values.
 #' @inheritParams params
 #' @return A numeric vector.
-#' @seealso \code{\link[VGAM]{dpareto}}
 #' @name pareto
+#' @seealso [VGAM::dpareto()]
 #' @examples
 #' x <- seq(0.01, 5, by = 0.01)
 #' plot(x, dpareto(x), type = "l")
@@ -34,6 +33,8 @@ NULL
 #' @rdname pareto
 #' @export
 dpareto <- function(x, scale = 1, shape = 1, log = FALSE) {
+  deprecate_soft("0.2.1", "dpareto()", id = "xpareto",
+                 details = "The 'pareto' distribution is not suitable for SSD data.")
   if (!length(x)) {
     return(numeric(0))
   }
@@ -44,6 +45,8 @@ dpareto <- function(x, scale = 1, shape = 1, log = FALSE) {
 #' @rdname pareto
 #' @export
 qpareto <- function(p, scale = 1, shape = 1, lower.tail = TRUE, log.p = FALSE) {
+  deprecate_soft("0.2.1", "qpareto()", id = "xpareto",
+                 details = "The 'pareto' distribution is not suitable for SSD data.")
   if (!length(p)) {
     return(numeric(0))
   }
@@ -53,6 +56,8 @@ qpareto <- function(p, scale = 1, shape = 1, lower.tail = TRUE, log.p = FALSE) {
 #' @rdname pareto
 #' @export
 ppareto <- function(q, scale = 1, shape = 1, lower.tail = TRUE, log.p = FALSE) {
+  deprecate_soft("0.2.1", "ppareto()", id = "xpareto",
+                 details = "The 'pareto' distribution is not suitable for SSD data.")
   if (!length(q)) {
     return(numeric(0))
   }
@@ -62,12 +67,16 @@ ppareto <- function(q, scale = 1, shape = 1, lower.tail = TRUE, log.p = FALSE) {
 #' @rdname pareto
 #' @export
 rpareto <- function(n, scale = 1, shape = 1) {
+  deprecate_soft("0.2.1", "rpareto()", id = "xpareto",
+                 details = "The 'pareto' distribution is not suitable for SSD data.")
   VGAM::rpareto(n, scale = scale, shape = shape)
 }
 
 #' @rdname pareto
 #' @export
 spareto <- function(x) {
+  deprecate_soft("0.2.1", "spareto()", id = "xpareto",
+                 details = "The 'pareto' distribution is not suitable for SSD data.")
   fit <- vglm(x ~ 1, VGAM::paretoff)
   list(
     start = list(shape = exp(unname(coef(fit)))),
