@@ -14,13 +14,13 @@
 
 #' Weibull Distribution
 #'
-#' Density, distribution function, quantile function and random generation for the weibull distribution with
-#' parameters shape and scale with default values.
+#' Density, distribution function, quantile function and random generation for 
+#' the weibull distribution with parameters shape and scale.
 #'
 #' @inheritParams params
 #' @param x A numeric vector of values.
 #' @return A numeric vector.
-#' @seealso \code{\link[stats]{dweibull}}
+#' @seealso [stats::dweibull()]
 #' @name weibull
 #' @examples
 #' x <- seq(0.01, 5, by = 0.01)
@@ -30,23 +30,26 @@ NULL
 #' @rdname weibull
 #' @export
 dweibull <- function(x, shape = 1, scale = 1, log = FALSE) {
-  stats::dweibull(x = x, shape = shape, scale = scale, log = log)
+  ddist("weibull", x,  shape = shape, scale = scale, 
+        log = log)
 }
 
 #' @rdname weibull
 #' @export
 pweibull <- function(q, shape = 1, scale = 1, lower.tail = TRUE, log.p = FALSE) {
-  stats::pweibull(q = q, shape = shape, scale = scale, lower.tail = lower.tail, log.p = log.p)
+  pdist("weibull", q = q, shape = shape, scale = scale, 
+        lower.tail = lower.tail, log.p = log.p)
 }
 
 #' @rdname weibull
 #' @export
 qweibull <- function(p, shape = 1, scale = 1, lower.tail = TRUE, log.p = FALSE) {
-  stats::qweibull(p = p, shape = shape, scale = scale, lower.tail = lower.tail, log.p = log.p)
+  qdist("weibull", p = p, shape = shape, scale = scale, 
+        lower.tail = lower.tail, log.p = log.p)
 }
 
 #' @rdname weibull
 #' @export
 rweibull <- function(n, shape = 1, scale = 1) {
-  stats::rweibull(n = n, shape = shape, scale = scale)
+  rdist("weibull", n = n, shape = shape, scale = scale)
 }
