@@ -21,22 +21,16 @@ test_that("manual", {
 
   expect_equal(
     ssd_hc(dists, average = FALSE)$est,
-    c(
-      1.07373870642628, 1.29945366523807, 1.76891782851293, 1.56256632555312,
-      1.68117483775796, 1.0871695998917
-    )
+    c(1.07373870642628, 1.29945366523807, 1.76891782851293, 1.56256632555312, 
+      1.68066107721146, 1.0871695998917)
   )
 
   set.seed(99)
   expect_equal(
     as.data.frame(ssd_hc(dists, ci = TRUE, nboot = 10)),
-    structure(list(
-      percent = 5, est = 1.25049782701963, se = 0.631766229432851,
-      lcl = 0.775282589272772, ucl = 2.60353063438925, dist = "average"
-    ), row.names = c(
-      NA,
-      -1L
-    ), class = "data.frame")
+    structure(list(percent = 5, est = 1.2504293469908, se = 0.631776851773594, 
+                   lcl = 0.775249435219941, ucl = 2.60353105288968, dist = "average"), row.names = c(NA, 
+                                                                                                     -1L), class = "data.frame")
   )
 
   dists <- ssd_gof(dists)
@@ -49,18 +43,12 @@ test_that("manual", {
     "gamma", "gompertz", "lgumbel", "llogis",
     "lnorm", "weibull"
   ))
-  expect_equal(dists$ad, c(
-    0.440080783302818, 0.602165187357315,
-    0.828638954899656, 0.487268240754265, 0.507033548166948, 0.434627293919434
-  ))
-  expect_equal(dists$ks, c(
-    0.11688217126248, 0.120189751040992, 0.158266487930008,
-    0.0993097760964311, 0.106514303667428, 0.116975804418597
-  ), cvm = c(
-    0.0553642028346856,
-    0.0822552288877461, 0.134017999007959, 0.0595308368054581, 0.0703316409091878,
-    0.0542672742561657
-  ))
+  expect_equal(dists$ad, c(0.440080783302818, 0.602165187357315, 0.828638954899656, 0.487268240754265, 
+                           0.506765995104718, 0.434627293919434))
+  expect_equal(dists$ks, c(0.11688217126248, 0.120189751040992, 0.158266487930008, 0.0993097760964311, 
+                           0.106478603062667, 0.116975804418597))
+  expect_equal(dists$cvm, c(0.0553642028346856, 0.0822552288877461, 0.134017999007959, 
+                            0.0595308368054581, 0.0702966462329144, 0.0542672742561657))
   expect_equal(dists$aic, c(
     237.630318352347, 237.61115441186,
     244.185952512763, 241.014872096207, 239.028432979095, 237.625291133194
